import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import React from 'react';
import PropTypes from 'prop-types';
import MultipleChoiceList from './multiple-choice-list';
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";
import FormGroup from '../form-group/form-group';
import { Checkbox as Pf4Checkbox } from "@patternfly/react-core/dist/esm/components/Checkbox/Checkbox.js";
import IsRequired from '../is-required/is-required';

var SingleCheckbox = function SingleCheckbox(props) {
  var _useFieldApi = useFieldApi(props),
      label = _useFieldApi.label,
      isRequired = _useFieldApi.isRequired,
      helperText = _useFieldApi.helperText,
      meta = _useFieldApi.meta,
      validateOnMount = _useFieldApi.validateOnMount,
      description = _useFieldApi.description,
      input = _useFieldApi.input,
      isReadOnly = _useFieldApi.isReadOnly,
      isDisabled = _useFieldApi.isDisabled,
      id = _useFieldApi.id,
      FormGroupProps = _useFieldApi.FormGroupProps,
      rest = _objectWithoutProperties(_useFieldApi, ["label", "isRequired", "helperText", "meta", "validateOnMount", "description", "input", "isReadOnly", "isDisabled", "id", "FormGroupProps"]);

  return /*#__PURE__*/React.createElement(FormGroup, {
    isRequired: isRequired,
    helperText: helperText,
    meta: meta,
    validateOnMount: validateOnMount,
    description: description,
    hideLabel: true,
    id: id || input.name,
    FormGroupProps: FormGroupProps
  }, /*#__PURE__*/React.createElement(Pf4Checkbox, _extends({
    isChecked: input.checked
  }, input, {
    id: id || input.name,
    label: isRequired ? /*#__PURE__*/React.createElement(IsRequired, null, label) : label,
    "aria-label": rest.name
  }, rest, {
    isDisabled: isDisabled || isReadOnly
  })));
};

SingleCheckbox.propTypes = {
  label: PropTypes.node,
  validateOnMount: PropTypes.bool,
  isReadOnly: PropTypes.bool,
  isRequired: PropTypes.bool,
  helperText: PropTypes.node,
  description: PropTypes.node,
  isDisabled: PropTypes.bool,
  id: PropTypes.string,
  FormGroupProps: PropTypes.object
};

var Checkbox = function Checkbox(_ref) {
  var options = _ref.options,
      props = _objectWithoutProperties(_ref, ["options"]);

  return options ? /*#__PURE__*/React.createElement(MultipleChoiceList, _extends({
    options: options
  }, props)) : /*#__PURE__*/React.createElement(SingleCheckbox, props);
};

Checkbox.propTypes = {
  options: PropTypes.arrayOf(PropTypes.shape({
    label: PropTypes.node,
    value: PropTypes.any
  }))
};
export default Checkbox;