import _extends from "@babel/runtime/helpers/extends";
import _typeof from "@babel/runtime/helpers/typeof";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import _toConsumableArray from "@babel/runtime/helpers/toConsumableArray";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React, { useState } from 'react';
import PropTypes from 'prop-types';
import { DualListSelector } from "@patternfly/react-core/dist/esm/components/DualListSelector/DualListSelector.js";
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";
import _isEqual from 'lodash/isEqual';
import DualListTree from '../dual-list-tree-select/dual-list-tree-select';
import FormGroup from '../form-group';
import DualListContext from '../dual-list-context';

var DualList = function DualList(props) {
  var _useFieldApi = useFieldApi(_objectSpread(_objectSpread({}, props), {}, {
    FieldProps: {
      isEqual: function isEqual(current, initial) {
        return _isEqual(_toConsumableArray(current || []).sort(), _toConsumableArray(initial || []).sort());
      }
    }
  })),
      label = _useFieldApi.label,
      isRequired = _useFieldApi.isRequired,
      helperText = _useFieldApi.helperText,
      meta = _useFieldApi.meta,
      validateOnMount = _useFieldApi.validateOnMount,
      description = _useFieldApi.description,
      hideLabel = _useFieldApi.hideLabel,
      id = _useFieldApi.id,
      input = _useFieldApi.input,
      FormGroupProps = _useFieldApi.FormGroupProps,
      options = _useFieldApi.options,
      getValueFromNode = _useFieldApi.getValueFromNode,
      isSearchable = _useFieldApi.isSearchable,
      isSortable = _useFieldApi.isSortable,
      rest = _objectWithoutProperties(_useFieldApi, ["label", "isRequired", "helperText", "meta", "validateOnMount", "description", "hideLabel", "id", "input", "FormGroupProps", "options", "getValueFromNode", "isSearchable", "isSortable"]);

  var _useState = useState(function () {
    return {
      left: isSortable && 'asc',
      right: isSortable && 'asc'
    };
  }),
      _useState2 = _slicedToArray(_useState, 2),
      sortConfig = _useState2[0],
      setSortConfig = _useState2[1];

  var value = input.value || [];
  var leftOptions;
  var rightOptions;
  var onListChange;
  var filterOption;

  if (!getValueFromNode) {
    leftOptions = options.filter(function (option) {
      return _typeof(option) === 'object' ? !value.includes(option.value) : !value.includes(option);
    }).map(function (option) {
      return option.label || option;
    });
    rightOptions = options.filter(function (option) {
      return _typeof(option) === 'object' ? value.includes(option.value) : value.includes(option);
    }).map(function (option) {
      return option.label || option;
    });

    onListChange = function onListChange(_newLeft, newRight) {
      return input.onChange(newRight);
    };

    filterOption = function filterOption(option, input) {
      return option.value ? option.value.includes(input) : option.includes(input);
    };
  } else {
    leftOptions = options.filter(function (option) {
      return option.value ? !value.includes(option.value) : !value.includes(getValueFromNode(option));
    }).map(function (option) {
      return option.label || option;
    });
    rightOptions = options.filter(function (option) {
      return option.value ? value.includes(option.value) : value.includes(getValueFromNode(option));
    }).map(function (option) {
      return option.label || option;
    });

    onListChange = function onListChange(_newLeft, newRight) {
      return input.onChange(newRight === null || newRight === void 0 ? void 0 : newRight.map(getValueFromNode));
    };

    filterOption = function filterOption(option, input) {
      return option.value ? option.value.includes(input) : getValueFromNode(option).includes(input);
    };
  }

  if (isSortable) {
    var sort = function sort(direction, a, b) {
      return direction === 'asc' ? a.localeCompare(b) : b.localeCompare(a);
    };

    if (!getValueFromNode) {
      leftOptions = leftOptions.sort(function (a, b) {
        return sort(sortConfig.left, a.label || a, b.label || b);
      });
      rightOptions = rightOptions.sort(function (a, b) {
        return sort(sortConfig.right, a.label || a, b.label || b);
      });
    } else {
      leftOptions = leftOptions.sort(function (a, b) {
        return sort(sortConfig.left, getValueFromNode(a.label || a), getValueFromNode(b.label || b));
      });
      rightOptions = rightOptions.sort(function (a, b) {
        return sort(sortConfig.right, getValueFromNode(a.label || a), getValueFromNode(b.label || b));
      });
    }
  }

  return /*#__PURE__*/React.createElement(FormGroup, {
    label: label,
    isRequired: isRequired,
    helperText: helperText,
    meta: meta,
    validateOnMount: validateOnMount,
    description: description,
    hideLabel: hideLabel,
    id: id || input.name,
    FormGroupProps: FormGroupProps
  }, /*#__PURE__*/React.createElement(DualListContext.Provider, {
    value: {
      sortConfig: sortConfig,
      setSortConfig: setSortConfig
    }
  }, /*#__PURE__*/React.createElement(DualListSelector, _extends({
    availableOptions: leftOptions,
    chosenOptions: rightOptions,
    onListChange: onListChange,
    id: id || input.name,
    isSearchable: isSearchable
  }, getValueFromNode && {
    addAll: onListChange,
    addSelected: onListChange,
    filterOption: filterOption,
    removeAll: onListChange,
    removeSelected: onListChange
  }, rest))));
};

DualList.propTypes = {
  label: PropTypes.node,
  validateOnMount: PropTypes.bool,
  isRequired: PropTypes.bool,
  helperText: PropTypes.node,
  description: PropTypes.node,
  hideLabel: PropTypes.bool,
  id: PropTypes.string,
  getValueFromNode: PropTypes.func,
  isSearchable: PropTypes.bool,
  isSortable: PropTypes.bool
};

var DualListWrapper = function DualListWrapper(props) {
  return props.isTree ? /*#__PURE__*/React.createElement(DualListTree, props) : /*#__PURE__*/React.createElement(DualList, props);
};

DualListWrapper.propTypes = {
  isTree: PropTypes.bool
};
export default DualListWrapper;