import _extends from "@babel/runtime/helpers/extends";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React, { useEffect, useState, useRef } from 'react';
import { createPortal } from 'react-dom';
import Option from './option';
import EmptyOption from './empty-options';
import './menu.css';

var getScrollParent = function getScrollParent(element) {
  var style = getComputedStyle(element);
  var excludeStaticParent = style.position === 'absolute';
  var overflowRx = /(auto|scroll)/;
  var docEl = document.documentElement;

  if (style.position === 'fixed') {
    return docEl;
  }

  for (var parent = element; parent = parent.parentElement;) {
    // eslint-disable-line
    style = getComputedStyle(parent);

    if (excludeStaticParent && style.position === 'static') {
      continue;
    }

    if (overflowRx.test(style.overflow + style.overflowY + style.overflowX)) {
      return parent;
    }
  }

  return docEl;
};

var getMenuPosition = function getMenuPosition(selectBase) {
  if (!selectBase) {
    return {};
  }

  return selectBase.getBoundingClientRect();
};

var checkScrollVisibility = function checkScrollVisibility(scrollableParent, selectRoot, menuRoot) {
  var parentProportions = scrollableParent.getBoundingClientRect();
  var rootProportions = selectRoot.getBoundingClientRect();
  var menuProportions = menuRoot.getBoundingClientRect();
  return {
    rootPosition: parentProportions.y,
    cropSize: rootProportions.y + rootProportions.height - parentProportions.y,
    maxHeight: window.innerHeight - menuProportions.top + 1
  };
};

var MenuPortal = function MenuPortal(_ref) {
  var selectToggleRef = _ref.selectToggleRef,
      menuPortalTarget = _ref.menuPortalTarget,
      children = _ref.children;

  var _useState = useState(getMenuPosition(selectToggleRef.current)),
      _useState2 = _slicedToArray(_useState, 2),
      position = _useState2[0],
      setPosition = _useState2[1];

  var _useState3 = useState({}),
      _useState4 = _slicedToArray(_useState3, 2),
      _useState4$ = _useState4[0],
      cropSize = _useState4$.cropSize,
      rootPosition = _useState4$.rootPosition,
      maxHeight = _useState4$.maxHeight,
      setCropSize = _useState4[1];

  var menuRef = useRef();
  useEffect(function () {
    setCropSize({
      maxHeight: window.innerHeight - menuRef.current.getBoundingClientRect().top - 4
    });
    var scrollParentElement = getScrollParent(selectToggleRef.current);

    var scrollHandler = function scrollHandler() {
      setCropSize(checkScrollVisibility(scrollParentElement, selectToggleRef.current, menuRef.current));
      setPosition(getMenuPosition(selectToggleRef.current));
    };

    var resizeHandler = function resizeHandler() {
      setCropSize(function (prevSize) {
        return _objectSpread(_objectSpread({}, prevSize), {}, {
          maxHeight: window.innerHeight - menuRef.current.getBoundingClientRect().top - 4
        });
      });
      setPosition(getMenuPosition(selectToggleRef.current));
    };

    scrollParentElement.addEventListener('scroll', scrollHandler, true);
    window.addEventListener('resize', resizeHandler, true);
    return function () {
      window.removeEventListener('resize', resizeHandler, true);
      scrollParentElement.removeEventListener('scroll', scrollHandler, true);
    };
  }, [selectToggleRef]);
  var top = position.top + position.height;
  var sizedMenu = React.cloneElement(children, {
    style: {
      maxHeight: cropSize < 0 ? maxHeight + cropSize : maxHeight,
      overflow: 'auto'
    }
  });
  var portalDiv = /*#__PURE__*/React.createElement("div", {
    ref: menuRef,
    className: "pf-c-select ddorg_pf4-component-mapper__select-portal-menu",
    style: {
      zIndex: 401,
      position: 'absolute',
      top: cropSize < 0 ? rootPosition : top,
      left: position.left,
      width: position.width,
      overflow: 'hidden'
    }
  }, cropSize < 0 ? /*#__PURE__*/React.createElement("div", {
    style: {
      position: 'relative',
      top: cropSize,
      width: position.width
    }
  }, sizedMenu) : sizedMenu);
  return createPortal(portalDiv, menuPortalTarget);
};

var Menu = function Menu(_ref2) {
  var noResultsMessage = _ref2.noResultsMessage,
      noOptionsMessage = _ref2.noOptionsMessage,
      filterOptions = _ref2.filterOptions,
      isSearchable = _ref2.isSearchable,
      filterValue = _ref2.filterValue,
      options = _ref2.options,
      getItemProps = _ref2.getItemProps,
      getInputProps = _ref2.getInputProps,
      highlightedIndex = _ref2.highlightedIndex,
      selectedItem = _ref2.selectedItem,
      isMulti = _ref2.isMulti,
      isFetching = _ref2.isFetching,
      menuPortalTarget = _ref2.menuPortalTarget,
      menuIsPortal = _ref2.menuIsPortal,
      selectToggleRef = _ref2.selectToggleRef;
  var filteredOptions = isSearchable ? filterOptions(options, filterValue) : options;
  var menuItems = /*#__PURE__*/React.createElement("ul", {
    className: "pf-c-select__menu".concat(menuIsPortal ? ' ddorg__pf4-component-mapper__select-menu-portal' : '')
  }, filteredOptions.length === 0 && /*#__PURE__*/React.createElement(EmptyOption, {
    isSearchable: isSearchable,
    noOptionsMessage: noOptionsMessage,
    noResultsMessage: noResultsMessage,
    getInputProps: getInputProps,
    isFetching: isFetching
  }), filteredOptions.map(function (item, index) {
    var itemProps = getItemProps({
      item: item,
      index: index,
      isActive: highlightedIndex === index,
      isSelected: isMulti ? !!selectedItem.find(function (_ref3) {
        var value = _ref3.value;
        return item.value === value;
      }) : selectedItem === item.value,
      onMouseUp: function onMouseUp(e) {
        return e.stopPropagation();
      } // we need this to prevent issues with portal menu not selecting a option

    });
    return /*#__PURE__*/React.createElement(Option, _extends({
      key: item.key || item.value || typeof item.label === 'string' && item.label || item,
      item: item
    }, itemProps));
  }));

  if (menuIsPortal) {
    return /*#__PURE__*/React.createElement(MenuPortal, {
      menuPortalTarget: menuPortalTarget,
      selectToggleRef: selectToggleRef
    }, menuItems);
  }

  return menuItems;
};

export default Menu;