import _extends from "@babel/runtime/helpers/extends";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _toConsumableArray from "@babel/runtime/helpers/toConsumableArray";
import _typeof from "@babel/runtime/helpers/typeof";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React, { useRef, useState } from 'react';
import PropTypes from 'prop-types';
import DataDrivenSelect from '@data-driven-forms/common/select';
import parseInternalValue from '@data-driven-forms/common/select/parse-internal-value';
import Downshift from 'downshift';
import CaretDownIcon from "@patternfly/react-icons/dist/esm/icons/caret-down-icon";
import CloseIcon from "@patternfly/react-icons/dist/esm/icons/close-icon";
import CircleNotchIcon from "@patternfly/react-icons/dist/esm/icons/circle-notch-icon";
import './select-styles.css';
import '@patternfly/react-styles/css/components/Select/select.css';
import '@patternfly/react-styles/css/components/Chip/chip.css';
import '@patternfly/react-styles/css/components/ChipGroup/chip-group.css';
import '@patternfly/react-styles/css/components/Divider/divider.css';
import Menu from './menu';
import ClearIndicator from './clear-indicator';
import ValueContainer from './value-container';

var _itemToString = function itemToString(value, isMulti, showMore, handleShowMore, handleChange) {
  if (!value) {
    return '';
  }

  if (Array.isArray(value)) {
    if (!value || value.length === 0) {
      return;
    }

    if (isMulti) {
      var visibleOptions = showMore ? value : value.slice(0, 3);
      return /*#__PURE__*/React.createElement("div", {
        className: "pf-c-chip-group pf-u-ml-sm",
        onClick: function onClick(event) {
          return event.stopPropagation();
        }
      }, /*#__PURE__*/React.createElement("ul", {
        className: "pf-c-chip-group__list",
        "aria-label": "Chip group category"
      }, visibleOptions.map(function (item, index) {
        var label = _typeof(item) === 'object' ? item.label : item;
        return /*#__PURE__*/React.createElement("li", {
          className: "pf-c-chip-group__list-item",
          onClick: function onClick(event) {
            return event.stopPropagation();
          },
          key: item.key || item.value || item
        }, /*#__PURE__*/React.createElement("div", {
          className: "pf-c-chip"
        }, /*#__PURE__*/React.createElement("span", {
          className: "pf-c-chip__text",
          id: "pf-random-id-".concat(index, "-").concat(label)
        }, label), /*#__PURE__*/React.createElement("button", {
          onClick: function onClick() {
            return handleChange(item);
          },
          className: "pf-c-button pf-m-plain",
          type: "button"
        }, /*#__PURE__*/React.createElement(CloseIcon, null))));
      }), value.length > 3 && /*#__PURE__*/React.createElement("li", {
        className: "pf-c-chip-group__list-item"
      }, /*#__PURE__*/React.createElement("button", {
        type: "button",
        onClick: handleShowMore,
        className: "pf-c-chip pf-m-overflow"
      }, /*#__PURE__*/React.createElement("span", {
        className: "pf-c-chip__text"
      }, showMore ? 'Show less' : "".concat(value.length - 3, " more"))))));
    }

    return value.map(function (item) {
      return _typeof(item) === 'object' ? item.label : item;
    });
  }

  if (_typeof(value) === 'object') {
    return value.label;
  }

  return value;
}; // TODO fix the value of internal select not to be an array all the time. It forces the filter value to be an array and it crashes sometimes.


var filterOptions = function filterOptions(options) {
  var filterValue = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '';
  return options.filter(function (_ref) {
    var label = _ref.label;
    var filter = Array.isArray(filterValue) && filterValue.length > 0 ? filterValue[0] : filterValue;
    return label.toLowerCase().includes(filter.toLowerCase());
  });
};

var getValue = function getValue(isMulti, option, value) {
  if (!isMulti || !option) {
    return option;
  }

  var isSelected = value.find(function (_ref2) {
    var value = _ref2.value;
    return value === option.value;
  });
  return isSelected ? value.filter(function (_ref3) {
    var value = _ref3.value;
    return value !== option.value;
  }) : [].concat(_toConsumableArray(value), [option]);
};

var _stateReducer = function stateReducer(state, changes, isMulti) {
  switch (changes.type) {
    case Downshift.stateChangeTypes.clickButton:
      return _objectSpread(_objectSpread(_objectSpread({}, state), changes), {}, {
        highlightedIndex: undefined,
        // reset the item focus to prevent initial scroll and portal menu warping
        inputValue: undefined
      });

    case Downshift.stateChangeTypes.keyDownEnter:
    case Downshift.stateChangeTypes.clickItem:
      return _objectSpread(_objectSpread({}, changes), {}, {
        isOpen: isMulti ? state.isOpen : !state.isOpen,
        highlightedIndex: state.highlightedIndex,
        inputValue: isMulti ? state.inputValue : changes.inputValue // prevent filter value change after option click

      });

    case Downshift.stateChangeTypes.controlledPropUpdatedSelectedItem:
      return _objectSpread(_objectSpread({}, changes), {}, {
        inputValue: state.inputValue
      });

    case Downshift.stateChangeTypes.mouseUp:
      if (typeof changes.inputValue === 'string') {
        return _objectSpread({}, changes);
      }

      if (Array.isArray(changes.inputValue) && typeof changes.inputValue[0] === 'string') {
        return _objectSpread(_objectSpread({}, changes), {}, {
          inputValue: changes.inputValue[0]
        });
      }

      if (state.isOpen === true && changes.isOpen === false && changes.inputValue) {
        return _objectSpread(_objectSpread(_objectSpread({}, state), changes), {}, {
          inputValue: ''
        });
      }

      return _objectSpread(_objectSpread({}, changes), {}, {
        inputValue: state.inputValue
      });

    default:
      return changes;
  }
};

var InternalSelect = function InternalSelect(_ref4) {
  var noResultsMessage = _ref4.noResultsMessage,
      noOptionsMessage = _ref4.noOptionsMessage,
      onChange = _ref4.onChange,
      options = _ref4.options,
      value = _ref4.value,
      simpleValue = _ref4.simpleValue,
      placeholder = _ref4.placeholder,
      isSearchable = _ref4.isSearchable,
      isDisabled = _ref4.isDisabled,
      isClearable = _ref4.isClearable,
      isMulti = _ref4.isMulti,
      isFetching = _ref4.isFetching,
      onInputChange = _ref4.onInputChange,
      loadingMessage = _ref4.loadingMessage,
      menuPortalTarget = _ref4.menuPortalTarget,
      menuIsPortal = _ref4.menuIsPortal,
      props = _objectWithoutProperties(_ref4, ["noResultsMessage", "noOptionsMessage", "onChange", "options", "value", "simpleValue", "placeholder", "isSearchable", "isDisabled", "isClearable", "isMulti", "isFetching", "onInputChange", "loadingMessage", "menuPortalTarget", "menuIsPortal"]);

  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      showMore = _useState2[0],
      setShowMore = _useState2[1];

  var inputRef = useRef();
  var selectToggleRef = useRef();
  var parsedValue = parseInternalValue(value);

  var handleShowMore = function handleShowMore() {
    return setShowMore(function (prev) {
      return !prev;
    });
  };

  var handleChange = function handleChange(option) {
    return onChange(getValue(isMulti, option, value));
  };

  return /*#__PURE__*/React.createElement(Downshift, {
    id: props.id || props.name,
    onChange: handleChange,
    itemToString: function itemToString(value) {
      return _itemToString(value, isMulti, showMore, handleShowMore, handleChange);
    },
    selectedItem: value || '',
    stateReducer: function stateReducer(state, changes) {
      return _stateReducer(state, changes, isMulti);
    },
    onInputValueChange: function onInputValueChange(inputValue, _ref5) {
      var selectedItem = _ref5.selectedItem;

      /**
       * Prevent firing te load options callback when selecting value not filtering
       */
      if (onInputChange && typeof inputValue === 'string' && (selectedItem === null || selectedItem === void 0 ? void 0 : selectedItem.label) !== inputValue) {
        onInputChange(inputValue);
      }
    }
  }, function (_ref6) {
    var isOpen = _ref6.isOpen,
        inputValue = _ref6.inputValue,
        itemToString = _ref6.itemToString,
        selectedItem = _ref6.selectedItem,
        clearSelection = _ref6.clearSelection,
        getInputProps = _ref6.getInputProps,
        getToggleButtonProps = _ref6.getToggleButtonProps,
        getItemProps = _ref6.getItemProps,
        highlightedIndex = _ref6.highlightedIndex;
    var toggleButtonProps = getToggleButtonProps();
    return /*#__PURE__*/React.createElement("div", {
      className: "pf-c-select"
    }, /*#__PURE__*/React.createElement("div", _extends({
      ref: selectToggleRef,
      disabled: isDisabled,
      className: "pf-c-select__toggle".concat(isDisabled ? ' pf-m-disabled' : '').concat(isSearchable ? ' pf-m-typeahead' : '', " ddorg__pf4-component-mapper__select-toggle")
    }, toggleButtonProps), /*#__PURE__*/React.createElement("div", {
      className: "pf-c-select_toggle-wrapper ddorg__pf4-component-mapper__select-toggle-wrapper"
    }, /*#__PURE__*/React.createElement(ValueContainer, {
      isMulti: isMulti,
      isSearchable: isSearchable,
      placeholder: placeholder,
      inputRef: inputRef,
      getInputProps: getInputProps,
      value: itemToString(selectedItem, isMulti, showMore, handleShowMore, handleChange)
    })), isClearable && parsedValue && /*#__PURE__*/React.createElement(ClearIndicator, {
      clearSelection: clearSelection
    }), /*#__PURE__*/React.createElement("span", {
      className: "pf-c-select__toggle-arrow"
    }, isFetching ? /*#__PURE__*/React.createElement(CircleNotchIcon, {
      className: "ddorg__pf4-component-mapper__select-loading-icon"
    }) : /*#__PURE__*/React.createElement(CaretDownIcon, null))), isOpen && /*#__PURE__*/React.createElement(Menu, {
      noResultsMessage: noResultsMessage,
      noOptionsMessage: noOptionsMessage,
      isFetching: isFetching,
      isDisabled: isDisabled,
      isSearchable: isSearchable,
      getInputProps: getInputProps,
      filterOptions: filterOptions,
      filterValue: inputValue,
      options: options,
      getItemProps: getItemProps,
      highlightedIndex: highlightedIndex,
      selectedItem: isMulti ? value : parsedValue,
      isMulti: isMulti,
      menuPortalTarget: menuPortalTarget,
      menuIsPortal: menuIsPortal,
      selectToggleRef: selectToggleRef
    }));
  });
};

InternalSelect.propTypes = {
  onChange: PropTypes.func.isRequired,
  options: PropTypes.arrayOf(PropTypes.shape({
    value: PropTypes.any,
    label: PropTypes.any
  })).isRequired,
  value: PropTypes.any,
  simpleValue: PropTypes.bool,
  placeholder: PropTypes.string,
  isSearchable: PropTypes.bool,
  id: PropTypes.string,
  name: PropTypes.string.isRequired,
  isDisabled: PropTypes.bool,
  isClearable: PropTypes.bool,
  noResultsMessage: PropTypes.node,
  noOptionsMessage: PropTypes.func,
  isMulti: PropTypes.bool,
  isFetching: PropTypes.bool,
  onInputChange: PropTypes.func,
  loadingMessage: PropTypes.node,
  menuPortalTarget: PropTypes.any,
  menuIsPortal: PropTypes.bool
};

var Select = function Select(_ref7) {
  var menuIsPortal = _ref7.menuIsPortal,
      props = _objectWithoutProperties(_ref7, ["menuIsPortal"]);

  var menuPortalTarget = menuIsPortal ? document.body : undefined;
  return /*#__PURE__*/React.createElement(DataDrivenSelect, _extends({
    SelectComponent: InternalSelect,
    menuPortalTarget: menuPortalTarget,
    menuIsPortal: menuIsPortal
  }, props));
};

Select.propTypes = {
  isSearchable: PropTypes.bool,
  showMoreLabel: PropTypes.node,
  showLessLabel: PropTypes.node,
  simpleValue: PropTypes.bool,
  value: PropTypes.any,
  options: PropTypes.arrayOf(PropTypes.shape({
    value: PropTypes.any,
    label: PropTypes.any
  })),
  onChange: PropTypes.func.isRequired,
  isMulti: PropTypes.bool,
  loadOptions: PropTypes.func,
  loadingMessage: PropTypes.node,
  updatingMessage: PropTypes.node,
  menuIsPortal: PropTypes.bool,
  placeholder: PropTypes.string,
  noResultsMessage: PropTypes.node,
  noOptionsMessage: PropTypes.node
};
Select.defaultProps = {
  showMoreLabel: 'more',
  showLessLabel: 'Show less',
  simpleValue: true,
  loadingMessage: 'Loading...',
  updatingMessage: 'Loading data...',
  options: [],
  menuIsPortal: false,
  placeholder: 'Choose...',
  isSearchable: false,
  isClearable: false,
  noResultsMessage: 'No results found',
  noOptionsMessage: 'No options'
};
export default Select;