import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React, { useState, useEffect } from 'react';
import { WizardNavItem } from "@patternfly/react-core/dist/esm/components/Wizard/WizardNavItem.js";
import { WizardNav } from "@patternfly/react-core/dist/esm/components/Wizard/WizardNav.js";
import isEqual from 'lodash/isEqual';
import get from 'lodash/get';
import PropTypes from 'prop-types';

var memoValues = function memoValues(initialValue) {
  var valueCache = initialValue;
  return function (value) {
    if (!isEqual(value, valueCache)) {
      valueCache = value;
      return true;
    }

    return false;
  };
};

var WizardNavigationInternal = React.memo(function (_ref) {
  var navSchema = _ref.navSchema,
      activeStepIndex = _ref.activeStepIndex,
      maxStepIndex = _ref.maxStepIndex,
      jumpToStep = _ref.jumpToStep,
      valid = _ref.valid,
      validating = _ref.validating;
  return navSchema.filter(function (field) {
    return field.primary;
  }).map(function (step) {
    var substeps = step.substepOf && navSchema.filter(function (field) {
      return field.substepOf === step.substepOf;
    });
    var isValid = valid && !validating;
    return /*#__PURE__*/React.createElement(WizardNavItem, {
      key: step.substepOf || step.name,
      content: step.substepOfTitle || step.title,
      isCurrent: substeps ? activeStepIndex >= step.index && activeStepIndex < step.index + substeps.length : activeStepIndex === step.index,
      isDisabled: isValid ? maxStepIndex < step.index : step.index > activeStepIndex,
      onNavItemClick: function onNavItemClick(ind) {
        return jumpToStep(ind, isValid);
      },
      step: step.index,
      type: "button"
    }, substeps && /*#__PURE__*/React.createElement(WizardNav, {
      returnList: true
    }, substeps.map(function (substep) {
      return /*#__PURE__*/React.createElement(WizardNavItem, {
        type: "button",
        key: substep.name,
        content: substep.title,
        isCurrent: activeStepIndex === substep.index,
        isDisabled: isValid ? maxStepIndex < substep.index : substep.index > activeStepIndex,
        onNavItemClick: function onNavItemClick(ind) {
          return jumpToStep(ind, isValid);
        },
        step: substep.index
      });
    })));
  });
}, isEqual);
WizardNavigationInternal.propTypes = {
  activeStepIndex: PropTypes.number.isRequired,
  maxStepIndex: PropTypes.number.isRequired,
  jumpToStep: PropTypes.func.isRequired,
  navSchema: PropTypes.array.isRequired,
  valid: PropTypes.bool.isRequired,
  validating: PropTypes.bool.isRequired
};

var WizardNavigation = function WizardNavigation(_ref2) {
  var setPrevSteps = _ref2.setPrevSteps,
      crossroads = _ref2.crossroads,
      values = _ref2.values,
      props = _objectWithoutProperties(_ref2, ["setPrevSteps", "crossroads", "values"]);

  var _useState = useState(function () {
    return memoValues(crossroads ? crossroads.reduce(function (acc, curr) {
      return _objectSpread(_objectSpread({}, acc), {}, _defineProperty({}, curr, get(values, curr)));
    }, {}) : {});
  }),
      _useState2 = _slicedToArray(_useState, 1),
      memoValue = _useState2[0];

  useEffect(function () {
    if (crossroads) {
      var modifiedRoad = crossroads.reduce(function (acc, curr) {
        return _objectSpread(_objectSpread({}, acc), {}, _defineProperty({}, curr, get(values, curr)));
      }, {});

      if (memoValue(modifiedRoad)) {
        setPrevSteps();
      }
    }
  });
  return /*#__PURE__*/React.createElement(WizardNavigationInternal, props);
};

WizardNavigation.propTypes = {
  setPrevSteps: PropTypes.func.isRequired,
  values: PropTypes.object.isRequired,
  crossroads: PropTypes.arrayOf(PropTypes.string)
};
export default WizardNavigation;