import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import React, { Fragment, useEffect, useRef } from 'react';
import { Title } from "@patternfly/react-core/dist/esm/components/Title/Title.js";
import { WizardBody } from "@patternfly/react-core/dist/esm/components/Wizard/WizardBody.js";
import PropTypes from 'prop-types';
import WizardStepButtons from './step-buttons';
export var RenderTitle = function RenderTitle(_ref) {
  var title = _ref.title,
      customTitle = _ref.customTitle;
  return customTitle ? customTitle : /*#__PURE__*/React.createElement(Title, {
    headingLevel: "h1",
    size: "xl"
  }, title);
};
RenderTitle.propTypes = {
  title: PropTypes.node,
  customTitle: PropTypes.node
};

var DefaultStepTemplate = function DefaultStepTemplate(_ref2) {
  var formFields = _ref2.formFields,
      formRef = _ref2.formRef,
      title = _ref2.title,
      customTitle = _ref2.customTitle,
      showTitle = _ref2.showTitle,
      showTitles = _ref2.showTitles;
  return /*#__PURE__*/React.createElement("div", {
    ref: formRef,
    className: "pf-c-form"
  }, (showTitles && showTitle !== false || showTitle) && /*#__PURE__*/React.createElement(RenderTitle, {
    title: title,
    customTitle: customTitle
  }), formFields);
};

DefaultStepTemplate.propTypes = {
  title: PropTypes.node,
  formFields: PropTypes.array.isRequired,
  formOptions: PropTypes.shape({
    renderForm: PropTypes.func.isRequired
  }).isRequired,
  showTitles: PropTypes.bool,
  showTitle: PropTypes.bool,
  customTitle: PropTypes.node,
  formRef: PropTypes.oneOfType([PropTypes.func, PropTypes.shape({
    current: PropTypes.instanceOf(Element)
  })])
};

var WizardStep = function WizardStep(_ref3) {
  var name = _ref3.name,
      title = _ref3.title,
      description = _ref3.description,
      fields = _ref3.fields,
      formOptions = _ref3.formOptions,
      showTitles = _ref3.showTitles,
      showTitle = _ref3.showTitle,
      customTitle = _ref3.customTitle,
      hasNoBodyPadding = _ref3.hasNoBodyPadding,
      StepTemplate = _ref3.StepTemplate,
      rest = _objectWithoutProperties(_ref3, ["name", "title", "description", "fields", "formOptions", "showTitles", "showTitle", "customTitle", "hasNoBodyPadding", "StepTemplate"]);

  var formRef = useRef();
  useEffect(function () {
    // HACK: I can not pass ref to WizardBody because it is not
    // wrapped by forwardRef. However, the step body (the one that overflows)
    // is the grand parent of the form element.
    var stepBody = formRef.current && formRef.current.parentNode.parentNode;
    stepBody && stepBody.scrollTo({
      top: 0,
      left: 0,
      behavior: 'smooth'
    });
  }, [name]);
  return /*#__PURE__*/React.createElement(Fragment, null, /*#__PURE__*/React.createElement(WizardBody, {
    hasNoBodyPadding: hasNoBodyPadding
  }, /*#__PURE__*/React.createElement(StepTemplate, _extends({
    formFields: fields.map(function (item) {
      return formOptions.renderForm([item], formOptions);
    }),
    name: name,
    title: title,
    description: description,
    formOptions: formOptions,
    showTitles: showTitles,
    showTitle: showTitle,
    customTitle: customTitle,
    hasNoBodyPadding: hasNoBodyPadding,
    formRef: formRef,
    fields: fields
  }, rest))), /*#__PURE__*/React.createElement(WizardStepButtons, _extends({
    formOptions: formOptions
  }, rest)));
};

WizardStep.propTypes = {
  title: PropTypes.node,
  description: PropTypes.node,
  fields: PropTypes.array.isRequired,
  formOptions: PropTypes.shape({
    renderForm: PropTypes.func.isRequired
  }).isRequired,
  showTitles: PropTypes.bool,
  showTitle: PropTypes.bool,
  customTitle: PropTypes.node,
  name: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
  hasNoBodyPadding: PropTypes.bool,
  StepTemplate: PropTypes.elementType
};
WizardStep.defaultProps = {
  StepTemplate: DefaultStepTemplate
};
export default WizardStep;